@@ -48,4 +48,10 @@ class RescaleApplicationRequest(RoaRequest):
 		return self.get_query_params().get('AppId')
 
 	def set_AppId(self,AppId):
-		self.add_query_param('AppId',AppId)
\ No newline at end of file
+		self.add_query_param('AppId',AppId)
+
+	def get_AutoEnableApplicationScalingRule(self):
+		return self.get_query_params().get('AutoEnableApplicationScalingRule')
+
+	def set_AutoEnableApplicationScalingRule(self,AutoEnableApplicationScalingRule):
+		self.add_query_param('AutoEnableApplicationScalingRule',AutoEnableApplicationScalingRule)
\ No newline at end of file
