@@ -56,6 +56,12 @@ class RollbackApplicationRequest(RoaRequest):
 	def set_BatchWaitTime(self,BatchWaitTime):
 		self.add_query_param('BatchWaitTime',BatchWaitTime)
 
+	def get_AutoEnableApplicationScalingRule(self):
+		return self.get_query_params().get('AutoEnableApplicationScalingRule')
+
+	def set_AutoEnableApplicationScalingRule(self,AutoEnableApplicationScalingRule):
+		self.add_query_param('AutoEnableApplicationScalingRule',AutoEnableApplicationScalingRule)
+
 	def get_UpdateStrategy(self):
 		return self.get_query_params().get('UpdateStrategy')
 
